@@ -1,25 +1,113 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::Util::Test::KENTNL;
-BEGIN {
-  $Dist::Zilla::Util::Test::KENTNL::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::Util::Test::KENTNL::VERSION = '0.01015824';
-}
+$Dist::Zilla::Util::Test::KENTNL::VERSION = '1.000000';
+#ABSTRACT: KENTNL's DZil plugin testing tool
 
-#ABSTRACT: KENTNL's DZil plugin testing tool.
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-use Try::Tiny;
+use Try::Tiny qw( try catch );
 use Dist::Zilla::Tester qw( Builder );
 use Sub::Exporter -setup => {
   exports => [ 'test_config', ],
-  groups  => [ default => [qw( -all )] ]
+  groups  => [ default => [qw( -all )] ],
 };
 use Test::DZil qw(simple_ini);
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub test_config {
   my ($conf) = shift;
   my $args = [];
@@ -98,13 +186,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Dist::Zilla::Util::Test::KENTNL - KENTNL's DZil plugin testing tool.
+Dist::Zilla::Util::Test::KENTNL - KENTNL's DZil plugin testing tool
 
 =head1 VERSION
 
-version 0.01015824
+version 1.000000
 
 =head1 METHODS
 
@@ -203,7 +293,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
